/* === This file is part of Calamares - <https://calamares.io> ===
 *
 *   SPDX-FileCopyrightText: 2014 Teo Mrnjavac <teo@kde.org>
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 *   Calamares is Free Software: see the License-Identifier above.
 *
 */

#ifndef LIBCALAMARESUI_TMAXOSMESSAGEBOX_H
#define LIBCALAMARESUI_TMAXOSMESSAGEBOX_H

#include "DllMacro.h"

#include <QDialog>
#include <QWidget>

class QHBoxLayout;
class QLabel;
class QMouseEvent;
class QObject;
class QPaintEvent;
class QPoint;
class QPushButton;
class QVBoxLayout;

namespace Calamares
{

class TmaxOsMessageBoxTitleBar : public QWidget
{
    Q_OBJECT
public:
    TmaxOsMessageBoxTitleBar( QWidget *parent );
    ~TmaxOsMessageBoxTitleBar();

    void setText( const QString& text );

protected:
    void mouseDoubleClickEvent( QMouseEvent *event ) override;
    void mousePressEvent( QMouseEvent *event ) override;
    void mouseMoveEvent( QMouseEvent *event ) override;
    bool eventFilter( QObject* obj, QEvent* event ) override;

    void paintEvent( QPaintEvent * ) override;

private slots:
    void onClicked();

private:
    QLabel* m_title;
    QPushButton* m_closeButton;

    QPoint m_pos;
};

class UIDLLEXPORT TmaxOsMessageBox : public QDialog
{
    Q_OBJECT
public:
    explicit TmaxOsMessageBox( QWidget* parent = nullptr );
    ~TmaxOsMessageBox() override {}

    void setTextTitleBar( const QString& text );

    void setImageObjectName( const QString& name );
    void setTextMain( const QString& text );
    void setTextSub( const QString& text );
    
    void setTextAcceptButton( const QString& text );
    void setTextRejectButton( const QString& text );

    void setAcceptButtonVisible( bool visible );
    void setRejectButtonVisible( bool visible );

public slots:
    void retranslate();

protected:
    void paintEvent( QPaintEvent * ) override;

protected:
    TmaxOsMessageBoxTitleBar* m_titleBar;
    QHBoxLayout* m_imageLayout;
    QLabel* m_image;
    QLabel* m_textMain;
    QLabel* m_textSub;
    QPushButton* m_accept;
    QPushButton* m_reject;
};

}  // namespace Calamares
#endif  // LIBCALAMARESUI_TMAXOSMESSAGEBOX_H
