/* === This file is part of Calamares - <https://calamares.io> ===
 *
 *   SPDX-FileCopyrightText: 2014 Teo Mrnjavac <teo@kde.org>
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 *   Calamares is Free Software: see the License-Identifier above.
 *
 */

#ifndef LIBCALAMARESUI_TMAXOSRADIOBUTTON_H
#define LIBCALAMARESUI_TMAXOSRADIOBUTTON_H

#include "DllMacro.h"

#include <QRadioButton>

class QHBoxLayout;

class QButtonGroup;
class QVBoxLayout;

namespace Calamares
{
class ClickableLabel;

/** @brief A radio button with fancy label next to it.
 *
 * The fancy label is used so that the text alongside the radio
 * button can word-wrap, be multi-line, and support rich text.
 *
 * The radio button itself can be retrieved with buttonWidget(),
 * and the whole behaves a lot like a label. Extra options can be
 * added to the display (options are hidden when the button is
 * not selected) with addOptionsComboBox().
 */
class UIDLLEXPORT TmaxOsRadioButton : public QWidget
{
    Q_OBJECT
public:
    explicit TmaxOsRadioButton( QWidget* parent = nullptr );
    ~TmaxOsRadioButton() override {}

    /// @brief Passes @p text on to the ClickableLabel
    void setTextMain( const QString& text );
    void setTextSub( const QString& text, bool warning = false );

    // Icon applies to the radio-button part
    void setIconSize( const QSize& size );
    QSize iconSize() const;
    void setIcon( const QIcon& icon );

    // Applies to the radio-button part
    void setChecked( bool checked );
    bool isChecked() const;

    /** @brief Adds the radio-button part to the given @p group
     *
     * For managing the pretty-radio-button in button groups like normal
     * radio buttons, call addToGroup() rather that group->addButton().
     */
    void addToGroup( QButtonGroup* group, int id = -1 );

    /// @brief Add a widget
    void addWidget( QWidget* );

private slots:
    /// Options are hidden when the radio button is off
    void toggleWidgets( bool checked );

protected:
	void paintEvent( QPaintEvent * ) override;

protected:
	QVBoxLayout* m_mainLayout;
    ClickableLabel* m_textMain;
    ClickableLabel* m_textSub;
    QRadioButton* m_radio;
	ClickableLabel* m_imgSub;
    QVBoxLayout* m_widgetsLayout;
};

}  // namespace Calamares
#endif  // LIBCALAMARESUI_TMAXOSRADIOBUTTON_H
